@@ -1,12 +1,38 @@
 package Langertha::Engine::Groq;
 our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: GroqCloud API
-$Langertha::Engine::Groq::VERSION = '0.007';
+$Langertha::Engine::Groq::VERSION = '0.008';
 use Moose;
 use Carp qw( croak );
 
 extends 'Langertha::Engine::OpenAI';
 
+sub all_models {qw(
+  allam-2-7b
+  deepseek-r1-distill-llama-70b
+  deepseek-r1-distill-qwen-32b
+  distil-whisper-large-v3-en
+  gemma2-9b-it
+  llama-3.1-8b-instant
+  llama-3.2-11b-vision-preview
+  llama-3.2-1b-preview
+  llama-3.2-3b-preview
+  llama-3.2-90b-vision-preview
+  llama-3.3-70b-specdec
+  llama-3.3-70b-versatile
+  llama-guard-3-8b
+  llama3-70b-8192
+  llama3-8b-8192
+  mistral-saba-24b
+  playai-tts
+  playai-tts-arabic
+  qwen-2.5-32b
+  qwen-2.5-coder-32b
+  qwen-qwq-32b
+  whisper-large-v3
+  whisper-large-v3-turbo
+)}
+
 sub _build_api_key {
   my ( $self ) = @_;
   return $ENV{LANGERTHA_GROQ_API_KEY}
@@ -41,7 +67,7 @@ Langertha::Engine::Groq - GroqCloud API
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
